from pathlib import Path
import subprocess


def capture(command):
    proc = subprocess.Popen(
        command,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE,
    )
    out, err = proc.communicate()
    return out, err, proc.returncode


def test_podman_compose_extends_w_file_subdir():
    """
    Test that podman-compose can execute podman-compose -f <file> up with extended File which
    includes a build context
    :return:
    """
    main_path = Path(__file__).parent.parent

    command_up = [
        "python3",
        str(main_path.joinpath("podman_compose.py")),
        "-f",
        str(main_path.joinpath("tests", "extends_w_file_subdir", "docker-compose.yml")),
        "up",
        "-d",
    ]

    command_check_container = [
        "podman",
        "container",
        "ps",
        "--all",
        "--format",
        '"{{.Image}}"',
    ]

    command_down = [
        "podman",
        "rmi",
        "--force",
        "localhost/subdir_test:me",
        "docker.io/library/busybox",
    ]

    out, err, returncode = capture(command_up)
    assert 0 == returncode
    # check container was created and exists
    out, err, returncode = capture(command_check_container)
    assert 0 == returncode
    assert out == b'"localhost/subdir_test:me"\n'
    out, err, returncode = capture(command_down)
    # cleanup test image(tags)
    assert 0 == returncode
    # check container did not exists anymore
    out, err, returncode = capture(command_check_container)
    assert 0 == returncode
    assert out == b""



import pytest

from podman_compose import parse_short_mount


@pytest.fixture
def multi_propagation_mount_str():
    return "/foo/bar:/baz:U,Z"


def test_parse_short_mount_multi_propagation(multi_propagation_mount_str):
    expected = {
        "type": "bind",
        "source": "/foo/bar",
        "target": "/baz",
        "bind": {
            "propagation": "U,Z",
        },
    }
    assert parse_short_mount(multi_propagation_mount_str, "/") == expected



import os
from setuptools import setup

try:
    readme = open(os.path.join(os.path.dirname(__file__), "README.md")).read()
except:
    readme = ""

setup(
    name="podman-compose",
    description="A script to run docker-compose.yml using podman",
    long_description=readme,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
    ],
    keywords="podman, podman-compose",
    author="Muayyad Alsadi",
    author_email="alsadi@gmail.com",
    url="https://github.com/containers/podman-compose",
    py_modules=["podman_compose"],
    entry_points={"console_scripts": ["podman-compose = podman_compose:main"]},
    include_package_data=True,
    license="GPL-2.0-only",
    install_requires=[
        "pyyaml",
        "python-dotenv",
    ],
    extras_require={
        "devel": [
            "flake8",
            "black",
            "pylint",
            "pre-commit",
        ]
    }
    # test_suite='tests',
    # tests_require=[
    #     'coverage',
    #     'pytest-cov',
    #     'pytest',
    #     'tox',
    # ]
)
